<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-tw?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// T
	'tw_description' => 'Integrà TextWheel en SPIP',
	'tw_slogan' => 'Gestioun de la tipougrafìa SPIP embé TextWheel',
];
